summaryrefslogtreecommitdiff
path: root/EmbeddedPkg/Ebl
diff options
context:
space:
mode:
authoroliviermartin <oliviermartin@6f19259b-4bc3-4df7-8a09-765794883524>2011-08-08 18:29:14 +0000
committeroliviermartin <oliviermartin@6f19259b-4bc3-4df7-8a09-765794883524>2011-08-08 18:29:14 +0000
commit7ca9e5a4010b0e16231173dfc1918685ffc3a1dd (patch)
treec242f6837827c6289131c5653be7993ae058a20d /EmbeddedPkg/Ebl
parent573d7e468eb83505a20ae3f828b67599cda23b3d (diff)
downloadedk2-platforms-7ca9e5a4010b0e16231173dfc1918685ffc3a1dd.tar.xz
EmbeddedPkg: Fix mispellings
git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@12101 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'EmbeddedPkg/Ebl')
-rw-r--r--EmbeddedPkg/Ebl/CmdTemplate.c4
-rw-r--r--EmbeddedPkg/Ebl/Command.c38
-rw-r--r--EmbeddedPkg/Ebl/Dir.c6
-rw-r--r--EmbeddedPkg/Ebl/Ebl.h60
-rw-r--r--EmbeddedPkg/Ebl/EfiDevice.c22
-rw-r--r--EmbeddedPkg/Ebl/Hob.c4
-rw-r--r--EmbeddedPkg/Ebl/HwDebug.c8
-rw-r--r--EmbeddedPkg/Ebl/HwIoDebug.c10
-rw-r--r--EmbeddedPkg/Ebl/Main.c36
-rw-r--r--EmbeddedPkg/Ebl/Script.c4
10 files changed, 96 insertions, 96 deletions
diff --git a/EmbeddedPkg/Ebl/CmdTemplate.c b/EmbeddedPkg/Ebl/CmdTemplate.c
index 328fda359b..e19d63a8b0 100644
--- a/EmbeddedPkg/Ebl/CmdTemplate.c
+++ b/EmbeddedPkg/Ebl/CmdTemplate.c
@@ -26,7 +26,7 @@
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
@@ -53,7 +53,7 @@ GLOBAL_REMOVE_IF_UNREFERENCED const EBL_COMMAND_TABLE mCmd%CommandName%Template[
/**
- Initialize the commands in this in this file
+ Initialize the commands in this file
**/
VOID
EblInitialize%CommandName%Cmd (
diff --git a/EmbeddedPkg/Ebl/Command.c b/EmbeddedPkg/Ebl/Command.c
index 73122e68a3..78ddcd1936 100644
--- a/EmbeddedPkg/Ebl/Command.c
+++ b/EmbeddedPkg/Ebl/Command.c
@@ -46,7 +46,7 @@ AsciiToUpper (
/**
- Case insensitve comparison of two Null-terminated Unicode strings with maximum
+ Case insensitive comparison of two Null-terminated Unicode strings with maximum
lengths, and returns the difference between the first mismatched Unicode
characters.
This function compares the Null-terminated Unicode string FirstString to the
@@ -94,9 +94,9 @@ AsciiStrniCmp (
/**
Add a command to the mCmdTable. If there is no free space in the command
table ASSERT. The mCmdTable is maintained in alphabetical order and the
- new entry is inserted into its sorted possition.
+ new entry is inserted into its sorted position.
- @param Entry Commnad Entry to add to the CmdTable
+ @param Entry Command Entry to add to the CmdTable
**/
VOID
@@ -139,7 +139,7 @@ EblAddCommand (
array of commands.
@param EntryArray Pointer to array of command entries
- @param ArrayCount Number of commnad entries to add
+ @param ArrayCount Number of command entries to add
**/
VOID
@@ -168,8 +168,8 @@ EBL_ADD_COMMAND_PROTOCOL gEblAddCommand = {
/**
Return the best matching command for the passed in command name. The match
- does not have to be exact, it just needs to be unqiue. This enables commands
- to be shortend to the smallest set of starting characters that is unique.
+ does not have to be exact, it just needs to be unique. This enables commands
+ to be shortened to the smallest set of starting characters that is unique.
@param CommandName Name of command to search for
@@ -250,7 +250,7 @@ CountNewLines (
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
@@ -300,14 +300,14 @@ EblHelpCmd (
/**
- Exit the EBL. If the commnad processor sees EFI_ABORTED return status it will
+ Exit the EBL. If the command processor sees EFI_ABORTED return status it will
exit the EBL.
Argv[0] - "exit"
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_ABORTED
@@ -388,7 +388,7 @@ EblExitCmd (
This AsciiPrint has to match the AsciiPrint in
EblPauseCmd.
- @param ElaspedTime Current timout value remaining
+ @param ElaspedTime Current timeout value remaining
**/
VOID
@@ -411,10 +411,10 @@ EblPauseCallback (
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS Timeout expired with no input
- @return EFI_TIMEOUT Stop procesing other commands on the same command line
+ @return EFI_TIMEOUT Stop processing other commands on the same command line
**/
EFI_STATUS
@@ -433,8 +433,8 @@ EblPauseCmd (
Status = EblGetCharKey (&Key, Delay, EblPauseCallback);
AsciiPrint ("\n");
- // If we timeout then the pause succeded thus return success
- // If we get a key return timout to stop other commnad on this cmd line
+ // If we timeout then the pause succeeded thus return success
+ // If we get a key return timeout to stop other command on this cmd line
return (Status == EFI_SUCCESS) ? EFI_TIMEOUT : EFI_SUCCESS;;
}
@@ -446,7 +446,7 @@ EblPauseCmd (
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
@@ -472,7 +472,7 @@ EblBreakPointCmd (
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
@@ -512,7 +512,7 @@ EblResetCmd (
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
@@ -693,7 +693,7 @@ OutputData (
Example hexdump.4 returns a width of 4.
- @param Argv Argv[0] is the comamnd name
+ @param Argv Argv[0] is the command name
@return Width of command
@@ -735,7 +735,7 @@ WidthFromCommandName (
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
diff --git a/EmbeddedPkg/Ebl/Dir.c b/EmbeddedPkg/Ebl/Dir.c
index 3bd072d584..5e28ecf61a 100644
--- a/EmbeddedPkg/Ebl/Dir.c
+++ b/EmbeddedPkg/Ebl/Dir.c
@@ -51,12 +51,12 @@ GLOBAL_REMOVE_IF_UNREFERENCED CHAR8 *gFvFileType[] = {
dir fs1:\efi *.efi; perform a dir on fs1: device in the efi directory but
only print out files that contain the string *.efi
dir fv1:\ ; perform a dir on fv1: device in the efi directory
- NOTE: fv devices do not contian subdirs
+ NOTE: fv devices do not contain subdirs
dir fv1:\ * PEIM ; will match all files of type PEIM
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
@@ -301,7 +301,7 @@ Done:
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
diff --git a/EmbeddedPkg/Ebl/Ebl.h b/EmbeddedPkg/Ebl/Ebl.h
index 5c322e5e97..03b4ba29fb 100644
--- a/EmbeddedPkg/Ebl/Ebl.h
+++ b/EmbeddedPkg/Ebl/Ebl.h
@@ -1,5 +1,5 @@
/** @file
- Include flie for basic command line parser for EBL (Embedded Boot Loader)
+ Include file for basic command line parser for EBL (Embedded Boot Loader)
Copyright (c) 2007, Intel Corporation. All rights reserved.<BR>
Portions copyright (c) 2008 - 2009, Apple Inc. All rights reserved.<BR>
@@ -58,14 +58,14 @@
//
// Prompt for the command line
//
-#define CMD_SEPERATOR ';'
-#define EBL_MAX_COMMAND_COUNT 0x100
-#define MAX_CMD_HISTORY 16
-#define MAX_CMD_LINE 256
-#define MAX_ARGS 32
+#define CMD_SEPARATOR ';'
+#define EBL_MAX_COMMAND_COUNT 0x100
+#define MAX_CMD_HISTORY 16
+#define MAX_CMD_LINE 256
+#define MAX_ARGS 32
-#define EBL_CR 0x0a
-#define EBL_LF 0x0d
+#define EBL_CR 0x0a
+#define EBL_LF 0x0d
#define EFI_SET_TIMER_TO_SECOND 10000000
@@ -73,7 +73,7 @@
EBL_COMMAND_TABLE *
EblGetCommand (
- IN CHAR8 *CommandName
+ IN CHAR8 *CommandName
);
@@ -88,8 +88,8 @@ EblPathToDevice (
BOOLEAN
EblAnyKeyToContinueQtoQuit (
- IN UINTN *CurrentRow,
- IN BOOLEAN PrefixNewline
+ IN UINTN *CurrentRow,
+ IN BOOLEAN PrefixNewline
);
VOID
@@ -109,7 +109,7 @@ EblShutdownExternalCmdTable (
VOID
EblSetTextColor (
- UINTN Attribute
+ UINTN Attribute
);
@@ -124,9 +124,9 @@ EblGetCharKey (
INTN
EFIAPI
AsciiStrniCmp (
- IN CONST CHAR8 *FirstString,
- IN CONST CHAR8 *SecondString,
- IN UINTN Length
+ IN CONST CHAR8 *FirstString,
+ IN CONST CHAR8 *SecondString,
+ IN UINTN Length
);
@@ -172,36 +172,36 @@ EblInitializeVariableCmds (
CHAR8 *
ParseArguments (
- IN CHAR8 *CmdLine,
- OUT UINTN *Argc,
- OUT CHAR8 **Argv
+ IN CHAR8 *CmdLine,
+ OUT UINTN *Argc,
+ OUT CHAR8 **Argv
);
EFI_STATUS
ProcessCmdLine (
- IN CHAR8 *CmdLine,
- IN UINTN MaxCmdLineSize
+ IN CHAR8 *CmdLine,
+ IN UINTN MaxCmdLineSize
);
EFI_STATUS
OutputData (
- IN UINT8 *Address,
- IN UINTN Length,
- IN UINTN Width,
- IN UINTN Offset
+ IN UINT8 *Address,
+ IN UINTN Length,
+ IN UINTN Width,
+ IN UINTN Offset
);
UINTN
WidthFromCommandName (
- IN CHAR8 *Argv,
- IN UINTN Default
+ IN CHAR8 *Argv,
+ IN UINTN Default
);
-extern UINTN gScreenColumns;
-extern UINTN gScreenRows;
-extern BOOLEAN gPageBreak;
-extern CHAR8 *gMemMapType[];
+extern UINTN gScreenColumns;
+extern UINTN gScreenRows;
+extern BOOLEAN gPageBreak;
+extern CHAR8 *gMemMapType[];
#endif
diff --git a/EmbeddedPkg/Ebl/EfiDevice.c b/EmbeddedPkg/Ebl/EfiDevice.c
index dafe0c9a05..dfdbc3fe78 100644
--- a/EmbeddedPkg/Ebl/EfiDevice.c
+++ b/EmbeddedPkg/Ebl/EfiDevice.c
@@ -196,7 +196,7 @@ EblPrintLoadFileInfo (
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
@@ -279,7 +279,7 @@ EblDeviceCmd (
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
@@ -353,7 +353,7 @@ EblStartCmd (
/**
Load a Firmware Volume (FV) into memory from a device. This causes drivers in
- the FV to be dispatched if the dependancies of the drivers are met.
+ the FV to be dispatched if the dependencies of the drivers are met.
Argv[0] - "loadfv"
Argv[1] - device name and path
@@ -364,7 +364,7 @@ EblStartCmd (
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
@@ -414,13 +414,13 @@ EblLoadFvCmd (
/**
Perform an EFI connect to connect devices that follow the EFI driver model.
If it is a PI system also call the dispatcher in case a new FV was made
- availible by one of the connect EFI drivers (this is not a common case).
+ available by one of the connect EFI drivers (this is not a common case).
Argv[0] - "connect"
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
@@ -542,7 +542,7 @@ CHAR8 *gMemMapType[] = {
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
@@ -628,7 +628,7 @@ EblMemMapCmd (
/**
- Load a file into memory and optionally jump to it. A load addres can be
+ Load a file into memory and optionally jump to it. A load address can be
specified or automatically allocated. A quoted command line can optionally
be passed into the image.
@@ -644,14 +644,14 @@ EblMemMapCmd (
in "EblCmdX Arg2 Arg3 Arg4" as the arguments.
go fv0:\EblCmdX * 0x10 "EblCmdX Arg2 Arg3 Arg4"; - load EblCmdX from FS0
- to location allocated by this comamnd and call the entry point at offset 0x10
+ to location allocated by this command and call the entry point at offset 0x10
passing in "EblCmdX Arg2 Arg3 Arg4" as the arguments.
go fv1:\EblCmdX 0x10000; Load EblCmdX to address 0x10000 and return
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
@@ -687,7 +687,7 @@ EblGoCmd (
// * Means allocate the buffer
Status = EfiReadAllocatePool (File, &Address, &Size);
- // EntryPoint is relatvie to the start of the image
+ // EntryPoint is relative to the start of the image
EntryPoint = (EBL_COMMMAND)((UINTN)EntryPoint + (UINTN)Address);
} else {
diff --git a/EmbeddedPkg/Ebl/Hob.c b/EmbeddedPkg/Ebl/Hob.c
index b2c042de22..b8c1c52752 100644
--- a/EmbeddedPkg/Ebl/Hob.c
+++ b/EmbeddedPkg/Ebl/Hob.c
@@ -103,14 +103,14 @@ GLOBAL_REMOVE_IF_UNREFERENCED char *mHobResourceType[] = {
/**
- Dump out the HOBs in the system. HOBs are defined in the PI specificaiton
+ Dump out the HOBs in the system. HOBs are defined in the PI specification
and they are used to hand off information from PEI to DXE.
Argv[0] - "hob"
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
diff --git a/EmbeddedPkg/Ebl/HwDebug.c b/EmbeddedPkg/Ebl/HwDebug.c
index b14d494d5d..2ecf9d6d31 100644
--- a/EmbeddedPkg/Ebl/HwDebug.c
+++ b/EmbeddedPkg/Ebl/HwDebug.c
@@ -71,7 +71,7 @@ EblMdCmd (
/**
Fill Memory with data
- Argv[0] - "mfill"[.#] # is optiona width 1, 2, 4, or 8. Default 4
+ Argv[0] - "mfill"[.#] # is optional width 1, 2, 4, or 8. Default 4
Argv[1] - Hex Address to fill
Argv[2] - Data to write (0x00 is default)
Argv[3] - Number of units to dump.
@@ -83,7 +83,7 @@ EblMdCmd (
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
@@ -163,7 +163,7 @@ CHAR8 *gPciSerialClassCodes[] = {
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
@@ -255,7 +255,7 @@ EblPciCmd (
Pci->GetLocation (Pci, &Seg, &Bus, &Dev, &Func);
if ((Bus == BusArg) && (Dev == DevArg) && (Func == FuncArg)) {
// Only print Segment if it is non zero. If you only have one PCI segment it is
- // redundent to print it out
+ // redundant to print it out
if (Seg != 0) {
AsciiPrint ("Seg:%d ", Seg);
}
diff --git a/EmbeddedPkg/Ebl/HwIoDebug.c b/EmbeddedPkg/Ebl/HwIoDebug.c
index a858ff31af..13f4d643f7 100644
--- a/EmbeddedPkg/Ebl/HwIoDebug.c
+++ b/EmbeddedPkg/Ebl/HwIoDebug.c
@@ -12,7 +12,7 @@
THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
- Commands useful for debugging hardware. IO commands seperated out as not all
+ Commands useful for debugging hardware. IO commands separated out as not all
processor architectures support the IO command.
**/
@@ -24,7 +24,7 @@
/**
Read from IO space
- Argv[0] - "ioread"[.#] # is optiona width 1, 2, or 4. Default 1
+ Argv[0] - "ioread"[.#] # is optional width 1, 2, or 4. Default 1
Argv[1] - Hex IO address
ior.4 0x3f8 ;Do a 32-bit IO Read from 0x3f8
@@ -32,7 +32,7 @@
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
@@ -73,7 +73,7 @@ EblIoReadCmd (
/**
Write to IO space
- Argv[0] - "iowrite"[.#] # is optiona width 1, 2, or 4. Default 1
+ Argv[0] - "iowrite"[.#] # is optional width 1, 2, or 4. Default 1
Argv[1] - Hex IO address
Argv[2] - Hex data to write
@@ -82,7 +82,7 @@ EblIoReadCmd (
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
diff --git a/EmbeddedPkg/Ebl/Script.c b/EmbeddedPkg/Ebl/Script.c
index 123ebf388c..7c2d58b0a4 100644
--- a/EmbeddedPkg/Ebl/Script.c
+++ b/EmbeddedPkg/Ebl/Script.c
@@ -26,7 +26,7 @@
supported:
LF : Unix, Mac OS X*, BeOS
CR+LF: MS-DOS*, Microsoft Windows*
- CR : Commodore, Apple II, and realy Mac OS
+ CR : Commodore, Apple II, and really Mac OS
LF+CR: for simplicity and completeness
Argv[0] - "script"
@@ -36,7 +36,7 @@
@param Argc Number of command arguments in Argv
@param Argv Array of strings that represent the parsed command line.
- Argv[0] is the comamnd name
+ Argv[0] is the command name
@return EFI_SUCCESS
diff --git a/EmbeddedPkg/Ebl/Main.c b/EmbeddedPkg/Ebl/Main.c
index 3d618419e6..e4879bcf97 100644
--- a/EmbeddedPkg/Ebl/Main.c
+++ b/EmbeddedPkg/Ebl/Main.c
@@ -151,7 +151,7 @@ Exit:
/**
Parse the CmdLine and break it up into Argc (arg count) and Argv (array of
- pointers to each argument). The Cmd buffer is altered and seperators are
+ pointers to each argument). The Cmd buffer is altered and separators are
converted to string terminators. This allows Argv to point into CmdLine.
A CmdLine can support multiple commands. The next command in the command line
is returned if it exists.
@@ -179,11 +179,11 @@ ParseArguments (
return NULL;
}
// Walk a single command line. A CMD_SEPERATOR allows mult commands on a single line
InQuote = FALSE;
LookingForArg = TRUE;
for (Char = CmdLine, Arg = 0; *Char != '\0'; Char++) {
- if (!InQuote && *Char == CMD_SEPERATOR) {
+ if (!InQuote && *Char == CMD_SEPARATOR) {
break;
}
@@ -194,7 +194,7 @@ ParseArguments (
}
if (LookingForArg) {
- // Look for the beging of an Argv[] entry
+ // Look for the beginning of an Argv[] entry
if (*Char == '"') {
Argv[Arg++] = ++Char;
LookingForArg = FALSE;
@@ -219,8 +219,8 @@ ParseArguments (
*Argc = Arg;
- if (*Char == CMD_SEPERATOR) {
- // Replace the command delimeter with null and return pointer to next command line
+ if (*Char == CMD_SEPARATOR) {
+ // Replace the command delimiter with null and return pointer to next command line
*Char = '\0';
return ++Char;
}
@@ -231,7 +231,7 @@ ParseArguments (
/**
Return a keypress or optionally timeout if a timeout value was passed in.
- An optional callback funciton is called evey second when waiting for a
+ An optional callback function is called every second when waiting for a
timeout.
@param Key EFI Key information returned
@@ -370,10 +370,10 @@ EblSetTextColor (
/**
- Collect the keyboard input for a cmd line. Carage Return, New Line, or ESC
+ Collect the keyboard input for a cmd line. Carriage Return, New Line, or ESC
terminates the command line. You can edit the command line via left arrow,
delete and backspace and they all back up and erase the command line.
- No edit of commnad line is possible without deletion at this time!
+ No edit of command line is possible without deletion at this time!
The up arrow and down arrow fill Cmd with information from the history
buffer.
@@ -516,7 +516,7 @@ EblPrompt (
/**
- Parse a command line and execute the commands. The ; seperator allows
+ Parse a command line and execute the commands. The ; separator allows
multiple commands for each command line. Stop processing if one of the
commands returns an error.
@@ -538,7 +538,7 @@ ProcessCmdLine (
UINTN Argc;
CHAR8 *Argv[MAX_ARGS];
- // Parse the command line. The loop processes commands seperated by ;
+ // Parse the command line. The loop processes commands separated by ;
for (Ptr = CmdLine, Status = EFI_SUCCESS; Ptr != NULL;) {
Ptr = ParseArguments (Ptr, &Argc, Argv);
if (Argc != 0) {
@@ -550,7 +550,7 @@ ProcessCmdLine (
// exit command so lets exit
break;
} else if (Status == EFI_TIMEOUT) {
- // pause command got imput so don't process any more cmd on this cmd line
+ // pause command got input so don't process any more cmd on this cmd line
break;
} else if (EFI_ERROR (Status)) {
AsciiPrint ("%a returned %r error\n", Cmd->Name, Status);
@@ -568,14 +568,14 @@ ProcessCmdLine (
/**
Embedded Boot Loader (EBL) - A simple EFI command line application for embedded
- devices. PcdEmbeddedAutomaticBootCommand is a complied in commnad line that
- gets executed automatically. The ; seperator allows multiple commands
+ devices. PcdEmbeddedAutomaticBootCommand is a complied in command line that
+ gets executed automatically. The ; separator allows multiple commands
for each command line.
@param ImageHandle EFI ImageHandle for this application.
@param SystemTable EFI system table
- @return EFI status of the applicaiton
+ @return EFI status of the application
**/
EFI_STATUS
@@ -592,7 +592,7 @@ EdkBootLoaderEntry (
UINTN CommandLineVariableSize = 0;
EFI_GUID VendorGuid;
- // Initialize tables of commnads
+ // Initialize tables of commands
EblInitializeCmdTable ();
EblInitializeDeviceCmd ();
EblInitializemdHwDebugCmds ();
@@ -605,7 +605,7 @@ EdkBootLoaderEntry (
EblInitializeVariableCmds ();
if (gST->ConOut == NULL) {
- DEBUG((EFI_D_ERROR,"Errot: No Console Output\n"));
+ DEBUG((EFI_D_ERROR,"Error: No Console Output\n"));
return EFI_NOT_READY;
}
@@ -627,7 +627,7 @@ EdkBootLoaderEntry (
EblPrintStartupBanner ();
- // Parse command line and handle commands seperated by ;
+ // Parse command line and handle commands separated by ;
// The loop prints the prompt gets user input and saves history
// Look for a variable with a default command line, otherwise use the Pcd
@@ -179,11 +179,11 @@ ParseArguments (
return NULL;
}
- // Walk a single command line. A CMD_SEPERATOR allows mult commands on a single line
+ // Walk a single command line. A CMD_SEPARATOR allows multiple commands on a single line
InQuote = FALSE;
LookingForArg = TRUE;